Module proxy

Module proxy 

Proxy file generation for ff-preview.

This module is only compiled when the proxy feature is enabled. It provides ProxyGenerator for generating lower-resolution proxy files from original media using ff_pipeline::Pipeline internally.

Structs

ProxyGenerator
Generates a lower-resolution proxy file from an original media file.
ProxyJob
A handle to a running background proxy generation job.

Enums

ProxyResolution
Output resolution for a proxy file, expressed as a fraction of the source.