Proxy file generation for ff-preview.
This module is only compiled when the proxy feature is enabled.
It provides ProxyGenerator for generating lower-resolution proxy files
from original media using ff_pipeline::Pipeline internally.
Structs
- Proxy
Generator - Generates a lower-resolution proxy file from an original media file.
- Proxy
Job - A handle to a running background proxy generation job.
Enums
- Proxy
Resolution - Output resolution for a proxy file, expressed as a fraction of the source.